@@ -1,43 +1,41 @@
-# ------------------------------------
+# --------------------------------------
 # Author: Andreas Alfons
-#         Erasmus University Rotterdam
-# ------------------------------------
+#         Erasmus Universiteit Rotterdam
+# --------------------------------------
 
 #' Access or set information on resampling-based prediction error results
-#' 
-#' Retrieve or set the names of resampling-based prediction error results, 
-#' retrieve or set the identifiers of the models, or retrieve the number of 
+#'
+#' Retrieve or set the names of resampling-based prediction error results,
+#' retrieve or set the identifiers of the models, or retrieve the number of
 #' prediction error results or included models.
-#' 
+#'
 #' @rdname accessors
 #' @name accessors
-#' 
-#' @param x  an object inheriting from class \code{"perry"} or 
+#'
+#' @param x  an object inheriting from class \code{"perry"} or
 #' \code{"perrySelect"} that contains prediction error results.
 #' @param value  a vector of replacement values.
-#' 
-#' @return 
-#' \code{peNames} returns the names of the prediction error results.  The 
+#'
+#' @return
+#' \code{peNames} returns the names of the prediction error results.  The
 #' replacement function thereby returns them invisibly.
-#' 
-#' \code{fits} returns the identifiers of the models for objects inheriting 
-#' from class \code{"perrySelect"} and \code{NULL} for objects inheriting from 
-#' class \code{"perry"}.  The replacement function thereby returns those values 
+#'
+#' \code{fits} returns the identifiers of the models for objects inheriting
+#' from class \code{"perrySelect"} and \code{NULL} for objects inheriting from
+#' class \code{"perry"}.  The replacement function thereby returns those values
 #' invisibly.
-#' 
+#'
 #' \code{npe} returns the number of prediction error results.
-#' 
-#' \code{nfits} returns the number of models included in objects inheriting 
-#' from class \code{"perrySelect"} and \code{NULL} for objects inheriting from 
+#'
+#' \code{nfits} returns the number of models included in objects inheriting
+#' from class \code{"perrySelect"} and \code{NULL} for objects inheriting from
 #' class \code{"perry"}.
-#' 
+#'
 #' @author Andreas Alfons
-#' 
-#' @seealso \code{\link{perryFit}}, \code{\link{perrySelect}}, 
+#'
+#' @seealso \code{\link{perryFit}}, \code{\link{perrySelect}},
 #' \code{\link{perryTuning}}
-#' 
-#' @example inst/doc/examples/example-accessors.R
-#' 
+#'
 #' @keywords utilities
 
 NULL
@@ -47,10 +45,10 @@ NULL
 #' @export
 peNames <- function(x) UseMethod("peNames")
 
-#' @S3method peNames perry
+#' @export
 peNames.perry <- function(x) names(x$pe)
 
-#' @S3method peNames perrySelect
+#' @export
 peNames.perrySelect <- function(x) names(x$pe)[-1]
 
 
@@ -59,7 +57,7 @@ peNames.perrySelect <- function(x) names(x$pe)[-1]
 #' @export
 "peNames<-" <- function(x, value) UseMethod("peNames<-")
 
-#' @S3method peNames<- perry
+#' @export
 "peNames<-.perry" <- function(x, value) {
   object <- x
   names(object$pe) <- names(object$se) <- value
@@ -67,7 +65,7 @@ peNames.perrySelect <- function(x) names(x$pe)[-1]
   eval.parent(substitute(x <- object))
 }
 
-#' @S3method peNames<- perrySelect
+#' @export
 "peNames<-.perrySelect" <- function(x, value) {
   object <- x
   names(object$best) <- value
@@ -82,10 +80,10 @@ peNames.perrySelect <- function(x) names(x$pe)[-1]
 #' @export
 fits <- function(x) UseMethod("fits")
 
-#' @S3method fits perry
+#' @export
 fits.perry <- function(x) NULL
 
-#' @S3method fits perrySelect
+#' @export
 fits.perrySelect <- function(x) x$pe$Fit
 
 
@@ -94,10 +92,10 @@ fits.perrySelect <- function(x) x$pe$Fit
 #' @export
 "fits<-" <- function(x, value) UseMethod("fits<-")
 
-#' @S3method fits<- perry
+#' @export
 "fits<-.perry" <- function(x, value) eval.parent(substitute(x))
 
-#' @S3method fits<- perrySelect
+#' @export
 "fits<-.perrySelect" <- function(x, value) {
   object <- x
   if(is.factor(value)) value <- factor(as.character(value), levels=value)
@@ -115,10 +113,10 @@ fits.perrySelect <- function(x) x$pe$Fit
 #' @export
 npe <- function(x) UseMethod("npe")
 
-#' @S3method npe perry
+#' @export
 npe.perry <- function(x) length(x$pe)
 
-#' @S3method npe perrySelect
+#' @export
 npe.perrySelect <- function(x) ncol(x$pe) - 1
 
 
@@ -126,41 +124,43 @@ npe.perrySelect <- function(x) ncol(x$pe) - 1
 #' @export
 nfits <- function(x) UseMethod("nfits")
 
-#' @S3method nfits perry
-#' @S3method nfits perrySelect
-nfits.perry <- nfits.perrySelect <- function(x) nrow(x$pe)
+#' @export
+nfits.perry <- function(x) nrow(x$pe)
+
+#' @export
+nfits.perrySelect <- function(x) nrow(x$pe)
 
 
 # ## @rdname accessors
 # ## @export
 # getR <- function(x) UseMethod("getR")
-# 
+#
 # ## @S3method getR cvFolds
 # ## @S3method getR randomSplits
 # ## @S3method getR bootSamples
 # getR.cvFolds <- getR.randomSplits <- getR.bootSamples <- function(x) x$R
-# 
+#
 # ## @S3method getR perry
 # ## @S3method getR perrySelect
 # getR.perry <- getR.perrySelect <- function(x) getR(x$splits)
 
 # -------------------------
 
-#' @S3method coef perryTuning
+#' @export
 coef.perryTuning <- function(object, ...) {
   finalModel <- object$finalModel
   if(is.null(finalModel)) stop("final model not available")
   coef(finalModel, ...)
 }
 
-#' @S3method fitted perryTuning
+#' @export
 fitted.perryTuning <- function(object, ...) {
   finalModel <- object$finalModel
   if(is.null(finalModel)) stop("final model not available")
   fitted(finalModel, ...)
 }
 
-#' @S3method residuals perryTuning
+#' @export
 residuals.perryTuning <- function(object, ...) {
   finalModel <- object$finalModel
   if(is.null(finalModel)) stop("final model not available")
